<?php
// Файл: modules/tracks.php

// Получение списка треков пользователя
$user_id = $_SESSION['user_id'];
$stmt = $mysqli->prepare("SELECT * FROM tracks WHERE user_id = ? ORDER BY created_at DESC");
$stmt->bind_param("i", $user_id);
$stmt->execute();
$tracks = $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
$stmt->close();

// Функция для безопасного вывода данных
function e($value) {
    return htmlspecialchars($value, ENT_QUOTES, 'UTF-8');
}

// Функция для генерации URL пути
function getUrl($path) {
    return e(str_replace($_SERVER['DOCUMENT_ROOT'], '', $path));
}
?>

<div class="d-flex justify-content-between align-items-center mb-4">
    <h2>Управление треками</h2>
    <div>
        <button class="btn btn-primary me-2" data-bs-toggle="modal" data-bs-target="#uploadTrackModal">
            <i class="bi bi-upload"></i> Загрузить новый трек
        </button>
        <div class="btn-group" role="group" aria-label="Переключение вида">
            <button type="button" class="btn btn-outline-secondary active" id="cardViewBtn">
                <i class="bi bi-grid"></i> Карточки
            </button>
            <button type="button" class="btn btn-outline-secondary" id="listViewBtn">
                <i class="bi bi-list"></i> Список
            </button>
        </div>
    </div>
</div>

<div id="trackContainer" class="track-list">
    <?php foreach ($tracks as $track): ?>
    <div class="track-item">
        <div class="track-cover">
            <img src="<?= getUrl($track['cover_path']) ?>" alt="Обложка">
        </div>
        <div class="track-info">
            <h3 class="track-name"><?= e($track['track_name']) ?></h3>
            <p class="track-artist"><?= e($track['artist_name']) ?></p>
            <p class="track-details">
                <span class="track-author">Музыка: <?= e($track['music_author']) ?></span>
                <span class="track-author">Текст: <?= e($track['lyrics_author']) ?></span>
            </p>
            <p class="track-date">Загружено: <?= date('d.m.Y', strtotime($track['created_at'])) ?></p>
        </div>
        <div class="track-actions">
            <button class="btn btn-sm btn-outline-primary play-track"
                    data-track-id="<?= $track['id'] ?>"
                    data-track-path="<?= getUrl($track['file_path']) ?>"
                    data-track-name="<?= e($track['track_name']) ?>"
                    data-artist-name="<?= e($track['artist_name']) ?>"
                    data-music-author="<?= e($track['music_author']) ?>"
                    data-lyrics-author="<?= e($track['lyrics_author']) ?>"
                    data-cover-path="<?= getUrl($track['cover_path']) ?>">
                <i class="bi bi-play-fill"></i>
            </button>
            <button class="btn btn-sm btn-outline-secondary edit-track" data-track-id="<?= $track['id'] ?>">
                <i class="bi bi-pencil"></i>
            </button>
            <button class="btn btn-sm btn-outline-danger delete-track" data-track-id="<?= $track['id'] ?>">
                <i class="bi bi-trash"></i>
            </button>
        </div>
    </div>
    <?php endforeach; ?>
</div>

<!-- Модальное окно для прослушивания трека -->
<div class="modal fade" id="playTrackModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Прослушивание трека</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <div class="text-center mb-3">
                    <img id="trackCover" src="" alt="Обложка трека" class="img-fluid rounded" style="max-width: 200px;">
                </div>
                <h4 id="trackName" class="text-center mb-2"></h4>
                <p id="artistName" class="text-center text-muted mb-2"></p>
                <p class="text-center mb-3">
                    <small id="trackAuthors" class="text-muted"></small>
                </p>
                <audio id="audioPlayer" controls style="width: 100%;">
                    Ваш браузер не поддерживает аудио элемент.
                </audio>
            </div>
        </div>
    </div>
</div>

<!-- Модальное окно для загрузки трека -->
<div class="modal fade" id="uploadTrackModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Загрузить новый трек</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form id="uploadTrackForm" enctype="multipart/form-data">
                    <div class="mb-3">
                        <label for="artistName" class="form-label">Имя артиста</label>
                        <input type="text" class="form-control" id="artistName" name="artistName" required>
                    </div>
                    <div class="mb-3">
                        <label for="trackName" class="form-label">Название трека</label>
                        <input type="text" class="form-control" id="trackName" name="trackName" required>
                    </div>
                    <div class="mb-3">
                        <label for="trackFile" class="form-label">Файл трека (WAV или MP3, макс. 100 МБ)</label>
                        <input type="file" class="form-control" id="trackFile" name="trackFile" accept=".wav,.mp3" required>
                    </div>
                    <div class="mb-3">
                        <audio id="audioPreview" controls style="width: 100%; display: none;"></audio>
                    </div>
                    <div class="mb-3">
                        <label for="coverImage" class="form-label">Обложка трека</label>
                        <input type="file" class="form-control" id="coverImage" name="coverImage" accept="image/*" required>
                    </div>
                    <div class="mb-3">
                        <img id="coverPreview" src="" alt="Предпросмотр обложки" style="max-width: 100%; display: none;">
                    </div>
                    <div class="mb-3">
                        <label for="lyrics" class="form-label">Текст трека</label>
                        <textarea class="form-control" id="lyrics" name="lyrics" rows="3"></textarea>
                    </div>
                    <div class="mb-3">
                        <label for="musicAuthor" class="form-label">Автор музыки</label>
                        <input type="text" class="form-control" id="musicAuthor" name="musicAuthor" required>
                    </div>
                    <div class="mb-3">
                        <label for="lyricsAuthor" class="form-label">Автор текста</label>
                        <input type="text" class="form-control" id="lyricsAuthor" name="lyricsAuthor" required>
                    </div>
                </form>
                <div class="progress mt-3" style="display: none;">
                    <div class="progress-bar" role="progressbar" style="width: 0%" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100"></div>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Отмена</button>
                <button type="button" class="btn btn-primary" id="uploadTrackBtn">Загрузить</button>
            </div>
        </div>
    </div>
</div>

<!-- Модальное окно для редактирования трека -->
<div class="modal fade" id="editTrackModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Редактировать трек</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form id="editTrackForm">
                    <input type="hidden" id="editTrackId" name="trackId">
                    <div class="mb-3">
                        <label for="editArtistName" class="form-label">Имя артиста</label>
                        <input type="text" class="form-control" id="editArtistName" name="artistName" required>
                    </div>
                    <div class="mb-3">
                        <label for="editTrackName" class="form-label">Название трека</label>
                        <input type="text" class="form-control" id="editTrackName" name="trackName" required>
                    </div>
                    <div class="mb-3">
                        <label for="editLyrics" class="form-label">Текст трека</label>
                        <textarea class="form-control" id="editLyrics" name="lyrics" rows="3"></textarea>
                    </div>
                    <div class="mb-3">
                        <label for="editMusicAuthor" class="form-label">Автор музыки</label>
                        <input type="text" class="form-control" id="editMusicAuthor" name="musicAuthor" required>
                    </div>
                    <div class="mb-3">
                        <label for="editLyricsAuthor" class="form-label">Автор текста</label>
                        <input type="text" class="form-control" id="editLyricsAuthor" name="lyricsAuthor" required>
                    </div>
                    <div class="mb-3">
                        <label for="editTrackFile" class="form-label">Новый файл трека (необязательно)</label>
                        <input type="file" class="form-control" id="editTrackFile" name="trackFile" accept=".wav,.mp3">
                    </div>
                    <div class="mb-3">
                        <label for="editCoverImage" class="form-label">Новая обложка трека (необязательно)</label>
                        <input type="file" class="form-control" id="editCoverImage" name="coverImage" accept="image/*">
                    </div>
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Отмена</button>
                <button type="button" class="btn btn-primary" id="saveEditTrackBtn">Сохранить изменения</button>
            </div>
        </div>
    </div>
</div>

<style>
.track-list {
    display: grid;
    grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
    gap: 20px;
}

.track-list.list-view {
    display: block;
}

.track-item {
    background-color: #fff;
    border-radius: 10px;
    box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
    overflow: hidden;
    transition: transform 0.3s ease;
}

.track-list.list-view .track-item {
    display: flex;
    margin-bottom: 20px;
    align-items: center;
}

.track-cover {
    position: relative;
    padding-top: 100%;
    overflow: hidden;
}

.track-list.list-view .track-cover {
    width: 100px;
    height: 100px;
    padding-top: 0;
    flex-shrink: 0;
}

.track-cover img {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    object-fit: cover;
}

.track-list.list-view .track-cover img {
    position: static;
}

.track-info {
    padding: 15px;
    flex-grow: 1;
}

.track-name {
    font-size: 18px;
    font-weight: bold;
    margin-bottom: 5px;
}

.track-artist {
    font-size: 16px;
    color: #666;
    margin-bottom: 10px;
}

.track-details {
    font-size: 14px;
    color: #888;
    margin-bottom: 5px;
}

.track-author {
    display: block;
    margin-bottom: 2px;
}

.track-date {
    font-size: 12px;
    color: #aaa;
    margin-bottom: 0;
}

.track-actions {
    display: flex;
    justify-content: space-around;
    padding: 10px;
    background-color: #f8f9fa;
}

.track-list.list-view .track-actions {
    flex-shrink: 0;
    flex-direction: column;
    justify-content: center;
    padding: 0 15px;
}

.track-actions .btn {
    flex: 1;
    margin: 0 5px;
}

.track-list.list-view .track-actions .btn {
    margin: 5px 0;
}

.modal-content {
    background-color: #f8f9fa;
    border: none;
    border-radius: 15px;
    box-shadow: 0 0 20px rgba(0,0,0,0.1);
}

.modal-header {
    border-bottom: none;
    padding: 20px 20px 0 20px;
}

.modal-body {
    padding: 20px;
}

#audioPlayer {
    background-color: #e9ecef;
    border-radius: 10px;
    padding: 10px;
}
</style>

<script>
$(document).ready(function() {
  function getUrl(path) {
    return path.replace(window.location.origin, '');
}
    // Функция для отображения уведомлений
    function showNotification(type, message) {
        const alertClass = type === 'success' ? 'alert-success' : 'alert-danger';
        const alert = $(`
            <div class="alert ${alertClass} alert-dismissible fade show" role="alert">
                ${message}
                <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
            </div>
        `);

        $('.container-fluid').prepend(alert);

        setTimeout(() => {
            alert.alert('close');
        }, 5000);
    }

    // Предпросмотр аудио
   $('#trackFile').change(function() {
       const file = this.files[0];
       if (file) {
           const audioPreview = $('#audioPreview');
           audioPreview.attr('src', URL.createObjectURL(file));
           audioPreview.show();
       }
   });

   // Предпросмотр обложки
   $('#coverImage').change(function() {
       const file = this.files[0];
       if (file) {
           const reader = new FileReader();
           reader.onload = function(e) {
               $('#coverPreview').attr('src', e.target.result).show();
           }
           reader.readAsDataURL(file);
       }
   });

    // Функция для обновления списка треков без перезагрузки страницы
    function updateTrackList() {
    $.ajax({
        url: 'scripts/track_actions.php?action=get_tracks',
        type: 'GET',
        dataType: 'json',
        success: function(response) {
            if (response.status === 'success') {
                // Очищаем текущий список треков
                $('#trackContainer').empty();

                if (response.tracks.length > 0) {
                    // Создаем временную переменную для HTML-контента
                    let tracksHtml = '';

                    // Добавляем обновленные треки
                    response.tracks.forEach(function(track) {
                        tracksHtml += `
                            <div class="track-item">
                                <div class="track-cover">
                                    <img src="${getUrl(track.cover_path)}" alt="Обложка">
                                </div>
                                <div class="track-info">
                                    <h3 class="track-name">${escapeHtml(track.track_name)}</h3>
                                    <p class="track-artist">${escapeHtml(track.artist_name)}</p>
                                    <p class="track-details">
                                        <span class="track-author">Музыка: ${escapeHtml(track.music_author)}</span>
                                        <span class="track-author">Текст: ${escapeHtml(track.lyrics_author)}</span>
                                    </p>
                                    <p class="track-date">Загружено: ${new Date(track.created_at).toLocaleDateString()}</p>
                                </div>
                                <div class="track-actions">
                                    <button class="btn btn-sm btn-outline-primary play-track"
                                            data-track-id="${track.id}"
                                            data-track-path="${getUrl(track.file_path)}"
                                            data-track-name="${escapeHtml(track.track_name)}"
                                            data-artist-name="${escapeHtml(track.artist_name)}"
                                            data-music-author="${escapeHtml(track.music_author)}"
                                            data-lyrics-author="${escapeHtml(track.lyrics_author)}"
                                            data-cover-path="${getUrl(track.cover_path)}">
                                        <i class="bi bi-play-fill"></i>
                                    </button>
                                    <button class="btn btn-sm btn-outline-secondary edit-track" data-track-id="${track.id}">
                                        <i class="bi bi-pencil"></i>
                                    </button>
                                    <button class="btn btn-sm btn-outline-danger delete-track" data-track-id="${track.id}">
                                        <i class="bi bi-trash"></i>
                                    </button>
                                </div>
                            </div>
                        `;
                    });

                    // Вставляем HTML за один раз
                    $('#trackContainer').append(tracksHtml);
                } else {
                    // Если нет треков, выводим сообщение
                    $('#trackContainer').append('<p class="no-tracks">Треки не найдены</p>');
                }
            } else {
                showNotification('error', 'Ошибка при обновлении списка треков: ' + response.message);
            }
        },
        error: function(xhr, status, error) {
            const errorMessage = xhr.status + ': ' + xhr.statusText;
            showNotification('error', 'Ошибка при получении списка треков (' + errorMessage + ')');
        }
    });
}

    // Вспомогательная функция для экранирования HTML
    function escapeHtml(unsafe) {
        return unsafe
            .replace(/&/g, "&amp;")
            .replace(/</g, "&lt;")
            .replace(/>/g, "&gt;")
            .replace(/"/g, "&quot;")
            .replace(/'/g, "&#039;");
    }

    // Переключение вида
    $('#cardViewBtn, #listViewBtn').click(function() {
        const isListView = this.id === 'listViewBtn';
        $('#trackContainer').toggleClass('list-view', isListView);
        $('#cardViewBtn, #listViewBtn').toggleClass('active');
        localStorage.setItem('trackViewMode', isListView ? 'list' : 'card');
    });

    // Загрузка сохраненного режима просмотра
    if (localStorage.getItem('trackViewMode') === 'list') {
        $('#listViewBtn').click();
    }

    // Прослушивание трека
    $(document).on('click', '.play-track', function() {
        const data = $(this).data();
        $('#trackCover').attr('src', data.coverPath);
        $('#trackName').text(data.trackName);
        $('#artistName').text(data.artistName);
        $('#trackAuthors').text(`Музыка: ${data.musicAuthor} | Текст: ${data.lyricsAuthor}`);
        $('#audioPlayer').attr('src', data.trackPath);
        $('#playTrackModal').modal('show');

        setTimeout(() => {
            document.getElementById('audioPlayer').play().catch(error => {
                console.error("Ошибка воспроизведения:", error);
                alert("Ошибка при воспроизведении трека. Пожалуйста, проверьте консоль для дополнительной информации.");
            });
        }, 500);
    });

    // Обработчик загрузки трека
    $('#uploadTrackBtn').click(function() {
        const formData = new FormData($('#uploadTrackForm')[0]);

        // Проверка размера файла
        const trackFile = $('#trackFile')[0].files[0];
        if (trackFile && trackFile.size > 100 * 1024 * 1024) {
            showNotification('error', 'Размер файла превышает 100 МБ');
            return;
        }

        // Проверка формата файла
        const allowedExtensions = ['mp3', 'wav'];
        const trackExtension = trackFile.name.split('.').pop().toLowerCase();
        if (!allowedExtensions.includes(trackExtension)) {
            showNotification('error', 'Недопустимый формат файла. Разрешены только MP3 и WAV');
            return;
        }

        $.ajax({
            url: 'scripts/track_actions.php?action=upload',
            type: 'POST',
            data: formData,
            processData: false,
            contentType: false,
            dataType: 'json',
            beforeSend: () => {
                $(this).prop('disabled', true).text('Загрузка...');
                // Показываем прогресс-бар
                $('.progress').show();
            },
            xhr: function() {
                const xhr = new window.XMLHttpRequest();
                xhr.upload.addEventListener("progress", function(evt) {
                    if (evt.lengthComputable) {
                        const percentComplete = evt.loaded / evt.total;
                        $('.progress-bar').width(percentComplete * 100 + '%');
                    }
                }, false);
                return xhr;
            },
            success: response => {
                if (response.status === 'success') {
                    showNotification('success', 'Трек успешно загружен!');
                    $('#uploadTrackModal').modal('hide');
                    $('#uploadTrackForm')[0].reset();
                    updateTrackList();
                } else {
                    showNotification('error', 'Ошибка: ' + response.message);
                }
            },
            error: (xhr, status, error) => {
                console.error('Ошибка AJAX:', status, error);
                showNotification('error', 'Произошла ошибка при загрузке трека. Пожалуйста, попробуйте еще раз.');
            },
            complete: () => {
                $(this).prop('disabled', false).text('Загрузить');
                // Скрываем и сбрасываем прогресс-бар
                $('.progress').hide();
                $('.progress-bar').width('0%');
            }
        });
    });

    // Обработчик удаления трека
    $(document).on('click', '.delete-track', function() {
        if (confirm('Вы уверены, что хотите удалить этот трек?')) {
            const trackId = $(this).data('track-id');
            $.ajax({
                url: 'scripts/track_actions.php?action=delete_track',
                type: 'POST',
                data: { trackId: trackId },
                dataType: 'json',
                success: response => {
                    if (response.status === 'success') {
                        showNotification('success', 'Трек успешно удален');
                        updateTrackList();
                    } else {
                        showNotification('error', response.message);
                    }
                },
                error: () => {
                    showNotification('error', 'Ошибка при удалении трека');
                }
            });
        }
    });

    // Обработчик редактирования трека
    $('#saveEditTrackBtn').click(function() {
        const formData = new FormData($('#editTrackForm')[0]);
        $.ajax({
            url: 'scripts/track_actions.php?action=update_track',
            type: 'POST',
            data: formData,
            processData: false,
            contentType: false,
            dataType: 'json',
            success: response => {
                if (response.status === 'success') {
                    showNotification('success', 'Трек успешно обновлен');
                    $('#editTrackModal').modal('hide');
                    updateTrackList();
                } else {
                    showNotification('error', response.message);
                }
            },
            error: () => {
                showNotification('error', 'Ошибка при обновлении трека');
            }
        });
    });

    // Обработчик открытия модального окна редактирования
    $(document).on('click', '.edit-track', function() {
        var trackId = $(this).data('track-id');

        $.ajax({
            url: 'scripts/track_actions.php?action=get_track',
            type: 'GET',
            data: { trackId: trackId },
            dataType: 'json',
            success: function(response) {
                if (response.status === 'success') {
                    $('#editTrackId').val(response.track.id);
                    $('#editArtistName').val(response.track.artist_name);
                    $('#editTrackName').val(response.track.track_name);
                    $('#editLyrics').val(response.track.lyrics);
                    $('#editMusicAuthor').val(response.track.music_author);
                    $('#editLyricsAuthor').val(response.track.lyrics_author);
                    $('#editTrackModal').modal('show');
                } else {
                    showNotification('error', response.message);
                }
            },
            error: function() {
                showNotification('error', 'Ошибка при получении данных трека');
            }
        });
    });
});
</script>
