<?php
require_once 'config.php';

function getAnalytics($user_id) {
    global $conn;

    // Получаем общее количество прослушиваний
    $stmt = mysqli_prepare($conn, "SELECT SUM(stream_count) as total_streams FROM tracks WHERE user_id = ?");
    mysqli_stmt_bind_param($stmt, "i", $user_id);
    mysqli_stmt_execute($stmt);
    $result = mysqli_stmt_get_result($stmt);
    $total_streams = mysqli_fetch_assoc($result)['total_streams'] ?? 0;

    // Получаем самый популярный трек
    $stmt = mysqli_prepare($conn, "SELECT title, stream_count FROM tracks WHERE user_id = ? ORDER BY stream_count DESC LIMIT 1");
    mysqli_stmt_bind_param($stmt, "i", $user_id);
    mysqli_stmt_execute($stmt);
    $result = mysqli_stmt_get_result($stmt);
    $top_track = mysqli_fetch_assoc($result);

    // Получаем данные о прослушиваниях по трекам
    $stmt = mysqli_prepare($conn, "SELECT title, stream_count as streams FROM tracks WHERE user_id = ? ORDER BY stream_count DESC");
    mysqli_stmt_bind_param($stmt, "i", $user_id);
    mysqli_stmt_execute($stmt);
    $result = mysqli_stmt_get_result($stmt);
    $track_streams = mysqli_fetch_all($result, MYSQLI_ASSOC);

    // Получаем данные о ежедневных прослушиваниях (пример: за последние 30 дней)
    // Примечание: эта часть предполагает, что у вас есть таблица daily_streams с полями date и streams
    // Если у вас нет такой таблицы, вам нужно будет адаптировать эту часть кода
    $stmt = mysqli_prepare($conn, "SELECT date, SUM(streams) as streams FROM daily_streams WHERE user_id = ? AND date >= DATE_SUB(CURDATE(), INTERVAL 30 DAY) GROUP BY date ORDER BY date");
    mysqli_stmt_bind_param($stmt, "i", $user_id);
    mysqli_stmt_execute($stmt);
    $result = mysqli_stmt_get_result($stmt);
    $daily_streams = mysqli_fetch_all($result, MYSQLI_ASSOC);

    return [
        'total_streams' => $total_streams,
        'top_track' => $top_track['title'] ?? 'Нет данных',
        'track_streams' => $track_streams,
        'daily_streams' => $daily_streams
    ];
}

function updateUserProfile($user_id, $new_name, $new_phone, $new_email) {
    global $conn;

    $stmt = mysqli_prepare($conn, "UPDATE users SET name = ?, phone = ?, email = ? WHERE id = ?");
    mysqli_stmt_bind_param($stmt, "sssi", $new_name, $new_phone, $new_email, $user_id);

    if (mysqli_stmt_execute($stmt)) {
        return ["success" => true, "message" => "Профиль успешно обновлен"];
    } else {
        return ["success" => false, "message" => "Ошибка при обновлении профиля: " . mysqli_error($conn)];
    }
}
?>
